flash_factors_set_to_zero: Set flash factors to zero
Description
Sets factor/loadings pairs to zero but does not remove them from the
flash object (so as to keep the indices of existing pairs
the same).
Usage
flash_factors_set_to_zero(flash, kset)
Value
The flash object from argument flash, with the
factors specified by kset set to zero.
Arguments
- flash
A flash or flash_fit object.
- kset
A vector of integers specifying which factor/loadings pairs to
set to zero.